@@ -1,7 +1,7 @@
 """Console script for tiff_stack_crop_tool."""
 import argparse
 import sys
-from .tiff_stack_crop_tool import crop_all_stacks
+from tiff_stack_crop_tool.tiff_stack_crop_tool import crop_all_stacks
 
 
 def main():
@@ -18,7 +18,7 @@ def main():
                              'scan1.tif, the corresponding stroke mask should be named scan1_stroke_mask.tif')
 
     args = parser.parse_args()
-    print("Arguments: " + str(args))
+    print("Arguments: " + str(args._))
     args = vars(args)
     crop_all_stacks(args)
     return 0
